===========
Async Oncue
===========


.. image:: https://img.shields.io/pypi/v/aiooncue.svg
        :target: https://pypi.python.org/pypi/aiooncue

.. image:: https://img.shields.io/travis/bdraco/aiooncue.svg
        :target: https://travis-ci.com/bdraco/aiooncue

.. image:: https://readthedocs.org/projects/aiooncue/badge/?version=latest
        :target: https://aiooncue.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Async for Oncue


* Free software: Apache Software License 2.0
* Documentation: https://aiooncue.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
